# 🕹 bandai: bandits for ai

[![CI/CD](https://github.com/Arkadiy-Vladimirov/bandai/actions/workflows/ci-cd.yaml/badge.svg)](https://github.com/Arkadiy-Vladimirov/bandai/actions/workflows/ci-cd.yaml)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)
[![PyPI version](https://img.shields.io/pypi/v/bandai-lib.svg)](https://pypi.org/project/bandai-lib/)

Simple multi-armed bandit implementations.

### Installation
Install from PyPI as
```
pip install bondai-lib
```
Check it works!
```bash
$ bondai
Hello from bandai!
```
